Crate bt_http_utils

Crate bt_http_utils 

Modules

stream_response

Structs

HttpClient
HttpClient: client: A Client instance from the reqwest crate for making HTTP requests. headers: A HeaderMap to store custom headers.
HttpResponse
HttpResponse: Represents the response from an HTTP request. status_code: The status code of the HTTP response. header: A HashMap containing the headers from the response. body: The body content of the HTTP response as a string.

Enums

ContentType
ContentType: An enum to specify the content type of the request or response. Currently supports JSON and TEXT.

Constants

DANGER_ACCEPT_INVALID_CERTS
DANGER_ACCEPT_INVALID_HOSTNAMES