Crate bt_http_utils
bt_
http_
utils
0.8.2
All Items
Crate Items
Modules
Structs
Enums
Constants
Crate
bt_
http_
utils
Modules

stream_
response
Structs

Http
Client
HttpClient: client: A Client instance from the reqwest crate for making HTTP requests. headers: A HeaderMap to store custom headers.
Http
Response
HttpResponse: Represents the response from an HTTP request. status_code: The status code of the HTTP response. header: A HashMap containing the headers from the response. body: The body content of the HTTP response as a string.
Enums

Content
Type
ContentType: An enum to specify the content type of the request or response. Currently supports JSON and TEXT.
Constants

DANGER_
ACCEPT_
INVALID_
CERTS
DANGER_
ACCEPT_
INVALID_
HOSTNAMES